@@ -2,11 +2,13 @@
 #this repository contains the full copyright notices and license terms.
 'Address'
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Not, Bool, Eval, If, Greater
+from trytond.pyson import Eval, If
+from trytond.pool import Pool
 
 STATES = {
-    'readonly': Not(Bool(Eval('active'))),
-}
+    'readonly': ~Eval('active'),
+    }
+DEPENDS = ['active']
 
 
 class Address(ModelSQL, ModelView):
@@ -14,23 +16,22 @@ class Address(ModelSQL, ModelView):
     _name = 'party.address'
     _description = __doc__
     party = fields.Many2One('party.party', 'Party', required=True,
-            ondelete='CASCADE', select=1,  states={
-                'readonly': If(Not(Bool(Eval('active'))),
-                    True, Greater(Eval('active_id', 0), 0)),
-            })
-    name = fields.Char('Name', states=STATES)
-    street = fields.Char('Street', states=STATES)
-    streetbis = fields.Char('Street (bis)', states=STATES)
-    zip = fields.Char('Zip', change_default=True,
-            states=STATES)
-    city = fields.Char('City', states=STATES)
+        ondelete='CASCADE', select=True,  states={
+            'readonly': If(~Eval('active'), True, Eval('id', 0) > 0),
+            },
+        depends=['active', 'id'])
+    name = fields.Char('Name', states=STATES, depends=DEPENDS)
+    street = fields.Char('Street', states=STATES, depends=DEPENDS)
+    streetbis = fields.Char('Street (bis)', states=STATES, depends=DEPENDS)
+    zip = fields.Char('Zip', states=STATES, depends=DEPENDS)
+    city = fields.Char('City', states=STATES, depends=DEPENDS)
     country = fields.Many2One('country.country', 'Country',
-        on_change=['country', 'subdivision'], states=STATES)
+        on_change=['country', 'subdivision'], states=STATES, depends=DEPENDS)
     subdivision = fields.Many2One("country.subdivision",
             'Subdivision', domain=[('country', '=', Eval('country'))],
-            states=STATES)
+            states=STATES, depends=['active', 'country'])
     active = fields.Boolean('Active')
-    sequence = fields.Integer("Sequence")
+    sequence = fields.Integer("Sequence", required=True)
     full_address = fields.Function(fields.Text('Full Address'),
             'get_full_address')
 
@@ -110,13 +111,13 @@ class Address(ModelSQL, ModelView):
         return super(Address, self).write(ids, vals)
 
     def on_change_country(self, vals):
-        subdivision_obj = self.pool.get('country.subdivision')
-        result = dict((k, vals.get(k, False))
+        subdivision_obj = Pool().get('country.subdivision')
+        result = dict((k, vals.get(k))
             for k in ('country', 'subdivision'))
         if vals['subdivision']:
             subdivision = subdivision_obj.browse(vals['subdivision'])
             if subdivision.country.id != vals['country']:
-                result['subdivision'] = False
+                result['subdivision'] = None
         return result
 
 Address()
